@@ -18,8 +18,9 @@ Usage::
     list_retained_messages_paginator: ListRetainedMessagesPaginator = client.get_paginator("list_retained_messages")
     ```
 """
-from typing import Iterator
+from typing import Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import ListRetainedMessagesResponseTypeDef, PaginatorConfigTypeDef
@@ -27,16 +28,26 @@ from .type_defs import ListRetainedMessagesResponseTypeDef, PaginatorConfigTypeD
 __all__ = ("ListRetainedMessagesPaginator",)
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListRetainedMessagesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/paginators.html#listretainedmessagespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListRetainedMessagesResponseTypeDef]:
+    ) -> _PageIterator[ListRetainedMessagesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/paginators.html#listretainedmessagespaginator)
         """
